# -*- coding: utf-8 -*-
# ----------------------------------------------------------------------------
# Copyright © Semi-ATE
# Licensed under the terms of the MIT License
# ----------------------------------------------------------------------------

from QScreenCast.QScreenCast import *

__version__ = "0.0.0"
__version__='0.1.24'
